@@ -6,7 +6,7 @@ Get software version information
 
 def release(full: bool = False) -> str:
     """Returns the software version number"""
-    result = "0.0.5"
+    result = "0.0.6"
     if full:
-        result += " (19 September 2019)"
+        result += " (04 October 2019)"
     return result
